/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWidgets.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qcommonstyle.sip"
#include <qcommonstyle.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCommonStyle.cpp"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qsizepolicy.sip"
#include <qsizepolicy.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCommonStyle.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 38 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCommonStyle.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 41 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCommonStyle.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 44 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCommonStyle.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qicon.sip"
#include <qicon.h>
#line 47 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCommonStyle.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qstyle.sip"
#include <qstyle.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCommonStyle.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpixmap.sip"
#include <qpixmap.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCommonStyle.cpp"
#line 923 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCommonStyle.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCommonStyle.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCommonStyle.cpp"
#line 749 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCommonStyle.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCommonStyle.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCommonStyle.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qapplication.sip"
#include <qapplication.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCommonStyle.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpalette.sip"
#include <qpalette.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCommonStyle.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 80 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCommonStyle.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 83 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCommonStyle.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 86 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCommonStyle.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfontmetrics.sip"
#include <qfontmetrics.h>
#line 89 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCommonStyle.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 94 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCommonStyle.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 97 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCommonStyle.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 100 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCommonStyle.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 103 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCommonStyle.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 106 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCommonStyle.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 109 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCommonStyle.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 112 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCommonStyle.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 115 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCommonStyle.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 118 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCommonStyle.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 121 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCommonStyle.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 124 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCommonStyle.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 127 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCommonStyle.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 130 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCommonStyle.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 133 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCommonStyle.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 136 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQCommonStyle.cpp"


class sipQCommonStyle : public ::QCommonStyle
{
public:
    sipQCommonStyle();
    virtual ~sipQCommonStyle();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    void polish(::QWidget*) SIP_OVERRIDE;
    void unpolish(::QWidget*) SIP_OVERRIDE;
    void polish(::QApplication*) SIP_OVERRIDE;
    void unpolish(::QApplication*) SIP_OVERRIDE;
    void polish(::QPalette&) SIP_OVERRIDE;
    ::QRect itemTextRect(const ::QFontMetrics&, const ::QRect&, int, bool, const ::QString&) const SIP_OVERRIDE;
    ::QRect itemPixmapRect(const ::QRect&, int, const ::QPixmap&) const SIP_OVERRIDE;
    void drawItemText(::QPainter*, const ::QRect&, int, const ::QPalette&, bool, const ::QString&, ::QPalette::ColorRole) const SIP_OVERRIDE;
    void drawItemPixmap(::QPainter*, const ::QRect&, int, const ::QPixmap&) const SIP_OVERRIDE;
    ::QPalette standardPalette() const SIP_OVERRIDE;
    void drawPrimitive(::QStyle::PrimitiveElement, const ::QStyleOption*, ::QPainter*, const ::QWidget*) const SIP_OVERRIDE;
    void drawControl(::QStyle::ControlElement, const ::QStyleOption*, ::QPainter*, const ::QWidget*) const SIP_OVERRIDE;
    ::QRect subElementRect(::QStyle::SubElement, const ::QStyleOption*, const ::QWidget*) const SIP_OVERRIDE;
    void drawComplexControl(::QStyle::ComplexControl, const ::QStyleOptionComplex*, ::QPainter*, const ::QWidget*) const SIP_OVERRIDE;
    ::QStyle::SubControl hitTestComplexControl(::QStyle::ComplexControl, const ::QStyleOptionComplex*, const ::QPoint&, const ::QWidget*) const SIP_OVERRIDE;
    ::QRect subControlRect(::QStyle::ComplexControl, const ::QStyleOptionComplex*, ::QStyle::SubControl, const ::QWidget*) const SIP_OVERRIDE;
    int pixelMetric(::QStyle::PixelMetric, const ::QStyleOption*, const ::QWidget*) const SIP_OVERRIDE;
    ::QSize sizeFromContents(::QStyle::ContentsType, const ::QStyleOption*, const ::QSize&, const ::QWidget*) const SIP_OVERRIDE;
    int styleHint(::QStyle::StyleHint, const ::QStyleOption*, const ::QWidget*, ::QStyleHintReturn*) const SIP_OVERRIDE;
    ::QPixmap standardPixmap(::QStyle::StandardPixmap, const ::QStyleOption*, const ::QWidget*) const SIP_OVERRIDE;
    ::QIcon standardIcon(::QStyle::StandardPixmap, const ::QStyleOption*, const ::QWidget*) const SIP_OVERRIDE;
    ::QPixmap generatedIconPixmap(::QIcon::Mode, const ::QPixmap&, const ::QStyleOption*) const SIP_OVERRIDE;
    int layoutSpacing(::QSizePolicy::ControlType, ::QSizePolicy::ControlType, ::Qt::Orientation, const ::QStyleOption*, const ::QWidget*) const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQCommonStyle(const sipQCommonStyle &);
    sipQCommonStyle &operator = (const sipQCommonStyle &);

    char sipPyMethods[30];
};

sipQCommonStyle::sipQCommonStyle(): ::QCommonStyle(), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQCommonStyle::~sipQCommonStyle()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQCommonStyle::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtWidgets_qt_metaobject(sipPySelf, sipType_QCommonStyle);

    return ::QCommonStyle::metaObject();
}

int sipQCommonStyle::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QCommonStyle::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtWidgets_qt_metacall(sipPySelf, sipType_QCommonStyle, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQCommonStyle::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtWidgets_qt_metacast(sipPySelf, sipType_QCommonStyle, _clname, &sipCpp) ? sipCpp : ::QCommonStyle::qt_metacast(_clname));
}

void sipQCommonStyle::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QCommonStyle::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCommonStyle::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QCommonStyle::connectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCommonStyle::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QCommonStyle::customEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCommonStyle::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QCommonStyle::childEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtWidgets_2(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCommonStyle::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QCommonStyle::timerEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtWidgets_3(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQCommonStyle::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QCommonStyle::eventFilter(a0, a1);

    extern bool sipVH_QtWidgets_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtWidgets_4(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQCommonStyle::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QCommonStyle::event(a0);

    extern bool sipVH_QtWidgets_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtWidgets_5(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCommonStyle::polish(::QWidget*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_polish);

    if (!sipMeth)
    {
        ::QCommonStyle::polish(a0);
        return;
    }

    extern void sipVH_QtWidgets_49(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWidget*);

    sipVH_QtWidgets_49(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCommonStyle::unpolish(::QWidget*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_unpolish);

    if (!sipMeth)
    {
        ::QCommonStyle::unpolish(a0);
        return;
    }

    extern void sipVH_QtWidgets_49(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWidget*);

    sipVH_QtWidgets_49(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCommonStyle::polish(::QApplication*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_polish);

    if (!sipMeth)
    {
        ::QCommonStyle::polish(a0);
        return;
    }

    extern void sipVH_QtWidgets_96(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QApplication*);

    sipVH_QtWidgets_96(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCommonStyle::unpolish(::QApplication*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_unpolish);

    if (!sipMeth)
    {
        ::QCommonStyle::unpolish(a0);
        return;
    }

    extern void sipVH_QtWidgets_96(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QApplication*);

    sipVH_QtWidgets_96(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCommonStyle::polish(::QPalette& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_polish);

    if (!sipMeth)
    {
        ::QCommonStyle::polish(a0);
        return;
    }

    extern void sipVH_QtWidgets_97(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPalette&);

    sipVH_QtWidgets_97(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QRect sipQCommonStyle::itemTextRect(const ::QFontMetrics& a0, const ::QRect& a1, int a2, bool a3, const ::QString& a4) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[12]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_itemTextRect);

    if (!sipMeth)
        return ::QCommonStyle::itemTextRect(a0, a1, a2, a3, a4);

    extern ::QRect sipVH_QtWidgets_98(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QFontMetrics&, const ::QRect&, int, bool, const ::QString&);

    return sipVH_QtWidgets_98(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3, a4);
}

::QRect sipQCommonStyle::itemPixmapRect(const ::QRect& a0, int a1, const ::QPixmap& a2) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[13]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_itemPixmapRect);

    if (!sipMeth)
        return ::QCommonStyle::itemPixmapRect(a0, a1, a2);

    extern ::QRect sipVH_QtWidgets_99(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QRect&, int, const ::QPixmap&);

    return sipVH_QtWidgets_99(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

void sipQCommonStyle::drawItemText(::QPainter*a0, const ::QRect& a1, int a2, const ::QPalette& a3, bool a4, const ::QString& a5, ::QPalette::ColorRole a6) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[14]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_drawItemText);

    if (!sipMeth)
    {
        ::QCommonStyle::drawItemText(a0, a1, a2, a3, a4, a5, a6);
        return;
    }

    extern void sipVH_QtWidgets_100(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPainter*, const ::QRect&, int, const ::QPalette&, bool, const ::QString&, ::QPalette::ColorRole);

    sipVH_QtWidgets_100(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3, a4, a5, a6);
}

void sipQCommonStyle::drawItemPixmap(::QPainter*a0, const ::QRect& a1, int a2, const ::QPixmap& a3) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[15]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_drawItemPixmap);

    if (!sipMeth)
    {
        ::QCommonStyle::drawItemPixmap(a0, a1, a2, a3);
        return;
    }

    extern void sipVH_QtWidgets_101(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPainter*, const ::QRect&, int, const ::QPixmap&);

    sipVH_QtWidgets_101(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}

::QPalette sipQCommonStyle::standardPalette() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[16]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_standardPalette);

    if (!sipMeth)
        return ::QCommonStyle::standardPalette();

    extern ::QPalette sipVH_QtWidgets_102(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_102(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQCommonStyle::drawPrimitive(::QStyle::PrimitiveElement a0, const ::QStyleOption*a1, ::QPainter*a2, const ::QWidget*a3) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[17]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_drawPrimitive);

    if (!sipMeth)
    {
        ::QCommonStyle::drawPrimitive(a0, a1, a2, a3);
        return;
    }

    extern void sipVH_QtWidgets_103(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QStyle::PrimitiveElement, const ::QStyleOption*, ::QPainter*, const ::QWidget*);

    sipVH_QtWidgets_103(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}

void sipQCommonStyle::drawControl(::QStyle::ControlElement a0, const ::QStyleOption*a1, ::QPainter*a2, const ::QWidget*a3) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[18]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_drawControl);

    if (!sipMeth)
    {
        ::QCommonStyle::drawControl(a0, a1, a2, a3);
        return;
    }

    extern void sipVH_QtWidgets_104(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QStyle::ControlElement, const ::QStyleOption*, ::QPainter*, const ::QWidget*);

    sipVH_QtWidgets_104(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}

::QRect sipQCommonStyle::subElementRect(::QStyle::SubElement a0, const ::QStyleOption*a1, const ::QWidget*a2) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[19]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_subElementRect);

    if (!sipMeth)
        return ::QCommonStyle::subElementRect(a0, a1, a2);

    extern ::QRect sipVH_QtWidgets_105(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QStyle::SubElement, const ::QStyleOption*, const ::QWidget*);

    return sipVH_QtWidgets_105(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

void sipQCommonStyle::drawComplexControl(::QStyle::ComplexControl a0, const ::QStyleOptionComplex*a1, ::QPainter*a2, const ::QWidget*a3) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[20]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_drawComplexControl);

    if (!sipMeth)
    {
        ::QCommonStyle::drawComplexControl(a0, a1, a2, a3);
        return;
    }

    extern void sipVH_QtWidgets_106(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QStyle::ComplexControl, const ::QStyleOptionComplex*, ::QPainter*, const ::QWidget*);

    sipVH_QtWidgets_106(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}

::QStyle::SubControl sipQCommonStyle::hitTestComplexControl(::QStyle::ComplexControl a0, const ::QStyleOptionComplex*a1, const ::QPoint& a2, const ::QWidget*a3) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[21]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_hitTestComplexControl);

    if (!sipMeth)
        return ::QCommonStyle::hitTestComplexControl(a0, a1, a2, a3);

    extern ::QStyle::SubControl sipVH_QtWidgets_107(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QStyle::ComplexControl, const ::QStyleOptionComplex*, const ::QPoint&, const ::QWidget*);

    return sipVH_QtWidgets_107(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}

::QRect sipQCommonStyle::subControlRect(::QStyle::ComplexControl a0, const ::QStyleOptionComplex*a1, ::QStyle::SubControl a2, const ::QWidget*a3) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[22]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_subControlRect);

    if (!sipMeth)
        return ::QCommonStyle::subControlRect(a0, a1, a2, a3);

    extern ::QRect sipVH_QtWidgets_108(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QStyle::ComplexControl, const ::QStyleOptionComplex*, ::QStyle::SubControl, const ::QWidget*);

    return sipVH_QtWidgets_108(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}

int sipQCommonStyle::pixelMetric(::QStyle::PixelMetric a0, const ::QStyleOption*a1, const ::QWidget*a2) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[23]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_pixelMetric);

    if (!sipMeth)
        return ::QCommonStyle::pixelMetric(a0, a1, a2);

    extern int sipVH_QtWidgets_109(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QStyle::PixelMetric, const ::QStyleOption*, const ::QWidget*);

    return sipVH_QtWidgets_109(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

::QSize sipQCommonStyle::sizeFromContents(::QStyle::ContentsType a0, const ::QStyleOption*a1, const ::QSize& a2, const ::QWidget*a3) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[24]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sizeFromContents);

    if (!sipMeth)
        return ::QCommonStyle::sizeFromContents(a0, a1, a2, a3);

    extern ::QSize sipVH_QtWidgets_110(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QStyle::ContentsType, const ::QStyleOption*, const ::QSize&, const ::QWidget*);

    return sipVH_QtWidgets_110(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}

int sipQCommonStyle::styleHint(::QStyle::StyleHint a0, const ::QStyleOption*a1, const ::QWidget*a2, ::QStyleHintReturn*a3) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[25]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_styleHint);

    if (!sipMeth)
        return ::QCommonStyle::styleHint(a0, a1, a2, a3);

    extern int sipVH_QtWidgets_111(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QStyle::StyleHint, const ::QStyleOption*, const ::QWidget*, ::QStyleHintReturn*);

    return sipVH_QtWidgets_111(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}

::QPixmap sipQCommonStyle::standardPixmap(::QStyle::StandardPixmap a0, const ::QStyleOption*a1, const ::QWidget*a2) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[26]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_standardPixmap);

    if (!sipMeth)
        return ::QCommonStyle::standardPixmap(a0, a1, a2);

    extern ::QPixmap sipVH_QtWidgets_112(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QStyle::StandardPixmap, const ::QStyleOption*, const ::QWidget*);

    return sipVH_QtWidgets_112(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

::QIcon sipQCommonStyle::standardIcon(::QStyle::StandardPixmap a0, const ::QStyleOption*a1, const ::QWidget*a2) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[27]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_standardIcon);

    if (!sipMeth)
        return ::QCommonStyle::standardIcon(a0, a1, a2);

    extern ::QIcon sipVH_QtWidgets_113(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QStyle::StandardPixmap, const ::QStyleOption*, const ::QWidget*);

    return sipVH_QtWidgets_113(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

::QPixmap sipQCommonStyle::generatedIconPixmap(::QIcon::Mode a0, const ::QPixmap& a1, const ::QStyleOption*a2) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[28]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_generatedIconPixmap);

    if (!sipMeth)
        return ::QCommonStyle::generatedIconPixmap(a0, a1, a2);

    extern ::QPixmap sipVH_QtWidgets_114(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QIcon::Mode, const ::QPixmap&, const ::QStyleOption*);

    return sipVH_QtWidgets_114(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

int sipQCommonStyle::layoutSpacing(::QSizePolicy::ControlType a0, ::QSizePolicy::ControlType a1, ::Qt::Orientation a2, const ::QStyleOption*a3, const ::QWidget*a4) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[29]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_layoutSpacing);

    if (!sipMeth)
        return ::QCommonStyle::layoutSpacing(a0, a1, a2, a3, a4);

    extern int sipVH_QtWidgets_115(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QSizePolicy::ControlType, ::QSizePolicy::ControlType, ::Qt::Orientation, const ::QStyleOption*, const ::QWidget*);

    return sipVH_QtWidgets_115(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3, a4);
}


PyDoc_STRVAR(doc_QCommonStyle_polish, "polish(self, widget: QWidget|None)\n"
"polish(self, app: QApplication|None)\n"
"polish(self, a0: QPalette) -> QPalette");

extern "C" {static PyObject *meth_QCommonStyle_polish(PyObject *, PyObject *);}
static PyObject *meth_QCommonStyle_polish(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QCommonStyle)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QWidget* a0;
        ::QCommonStyle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QCommonStyle, &sipCpp, sipType_QWidget, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QCommonStyle::polish(a0) : sipCpp->polish(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QApplication* a0;
        ::QCommonStyle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QCommonStyle, &sipCpp, sipType_QApplication, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QCommonStyle::polish(a0) : sipCpp->polish(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QPalette* a0;
        ::QCommonStyle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QCommonStyle, &sipCpp, sipType_QPalette, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QCommonStyle::polish(*a0) : sipCpp->polish(*a0));

            return sipConvertFromType(a0, sipType_QPalette, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCommonStyle, sipName_polish, doc_QCommonStyle_polish);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCommonStyle_unpolish, "unpolish(self, widget: QWidget|None)\n"
"unpolish(self, application: QApplication|None)");

extern "C" {static PyObject *meth_QCommonStyle_unpolish(PyObject *, PyObject *);}
static PyObject *meth_QCommonStyle_unpolish(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QCommonStyle)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QWidget* a0;
        ::QCommonStyle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QCommonStyle, &sipCpp, sipType_QWidget, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QCommonStyle::unpolish(a0) : sipCpp->unpolish(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QApplication* a0;
        ::QCommonStyle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QCommonStyle, &sipCpp, sipType_QApplication, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QCommonStyle::unpolish(a0) : sipCpp->unpolish(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCommonStyle, sipName_unpolish, doc_QCommonStyle_unpolish);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCommonStyle_drawPrimitive, "drawPrimitive(self, pe: QStyle.PrimitiveElement, opt: QStyleOption|None, p: QPainter|None, widget: QWidget|None = None)");

extern "C" {static PyObject *meth_QCommonStyle_drawPrimitive(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QCommonStyle_drawPrimitive(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QCommonStyle)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        const ::QStyleOption* a1;
        ::QPainter* a2;
        const ::QWidget* a3 = 0;
        const ::QCommonStyle *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_widget,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BEJ8J8|J8", &sipSelf, sipType_QCommonStyle, &sipCpp, sipType_QStyle_PrimitiveElement, &a0, sipType_QStyleOption, &a1, sipType_QPainter, &a2, sipType_QWidget, &a3))
        {
            (sipSelfWasArg ? sipCpp->::QCommonStyle::drawPrimitive(static_cast< ::QStyle::PrimitiveElement>(a0), a1, a2, a3) : sipCpp->drawPrimitive(static_cast< ::QStyle::PrimitiveElement>(a0), a1, a2, a3));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCommonStyle, sipName_drawPrimitive, doc_QCommonStyle_drawPrimitive);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCommonStyle_drawControl, "drawControl(self, element: QStyle.ControlElement, opt: QStyleOption|None, p: QPainter|None, widget: QWidget|None = None)");

extern "C" {static PyObject *meth_QCommonStyle_drawControl(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QCommonStyle_drawControl(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QCommonStyle)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        const ::QStyleOption* a1;
        ::QPainter* a2;
        const ::QWidget* a3 = 0;
        const ::QCommonStyle *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_widget,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BEJ8J8|J8", &sipSelf, sipType_QCommonStyle, &sipCpp, sipType_QStyle_ControlElement, &a0, sipType_QStyleOption, &a1, sipType_QPainter, &a2, sipType_QWidget, &a3))
        {
            (sipSelfWasArg ? sipCpp->::QCommonStyle::drawControl(static_cast< ::QStyle::ControlElement>(a0), a1, a2, a3) : sipCpp->drawControl(static_cast< ::QStyle::ControlElement>(a0), a1, a2, a3));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCommonStyle, sipName_drawControl, doc_QCommonStyle_drawControl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCommonStyle_subElementRect, "subElementRect(self, r: QStyle.SubElement, opt: QStyleOption|None, widget: QWidget|None = None) -> QRect");

extern "C" {static PyObject *meth_QCommonStyle_subElementRect(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QCommonStyle_subElementRect(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QCommonStyle)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        const ::QStyleOption* a1;
        const ::QWidget* a2 = 0;
        const ::QCommonStyle *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_widget,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BEJ8|J8", &sipSelf, sipType_QCommonStyle, &sipCpp, sipType_QStyle_SubElement, &a0, sipType_QStyleOption, &a1, sipType_QWidget, &a2))
        {
            ::QRect*sipRes;

            sipRes = new ::QRect((sipSelfWasArg ? sipCpp->::QCommonStyle::subElementRect(static_cast< ::QStyle::SubElement>(a0), a1, a2) : sipCpp->subElementRect(static_cast< ::QStyle::SubElement>(a0), a1, a2)));

            return sipConvertFromNewType(sipRes, sipType_QRect, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCommonStyle, sipName_subElementRect, doc_QCommonStyle_subElementRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCommonStyle_drawComplexControl, "drawComplexControl(self, cc: QStyle.ComplexControl, opt: QStyleOptionComplex|None, p: QPainter|None, widget: QWidget|None = None)");

extern "C" {static PyObject *meth_QCommonStyle_drawComplexControl(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QCommonStyle_drawComplexControl(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QCommonStyle)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        const ::QStyleOptionComplex* a1;
        ::QPainter* a2;
        const ::QWidget* a3 = 0;
        const ::QCommonStyle *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_widget,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BEJ8J8|J8", &sipSelf, sipType_QCommonStyle, &sipCpp, sipType_QStyle_ComplexControl, &a0, sipType_QStyleOptionComplex, &a1, sipType_QPainter, &a2, sipType_QWidget, &a3))
        {
            (sipSelfWasArg ? sipCpp->::QCommonStyle::drawComplexControl(static_cast< ::QStyle::ComplexControl>(a0), a1, a2, a3) : sipCpp->drawComplexControl(static_cast< ::QStyle::ComplexControl>(a0), a1, a2, a3));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCommonStyle, sipName_drawComplexControl, doc_QCommonStyle_drawComplexControl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCommonStyle_hitTestComplexControl, "hitTestComplexControl(self, cc: QStyle.ComplexControl, opt: QStyleOptionComplex|None, pt: QPoint, widget: QWidget|None = None) -> QStyle.SubControl");

extern "C" {static PyObject *meth_QCommonStyle_hitTestComplexControl(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QCommonStyle_hitTestComplexControl(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QCommonStyle)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        const ::QStyleOptionComplex* a1;
        const ::QPoint* a2;
        const ::QWidget* a3 = 0;
        const ::QCommonStyle *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_widget,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BEJ8J9|J8", &sipSelf, sipType_QCommonStyle, &sipCpp, sipType_QStyle_ComplexControl, &a0, sipType_QStyleOptionComplex, &a1, sipType_QPoint, &a2, sipType_QWidget, &a3))
        {
            ::QStyle::SubControl sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QCommonStyle::hitTestComplexControl(static_cast< ::QStyle::ComplexControl>(a0), a1, *a2, a3) : sipCpp->hitTestComplexControl(static_cast< ::QStyle::ComplexControl>(a0), a1, *a2, a3));

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QStyle_SubControl);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCommonStyle, sipName_hitTestComplexControl, doc_QCommonStyle_hitTestComplexControl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCommonStyle_subControlRect, "subControlRect(self, cc: QStyle.ComplexControl, opt: QStyleOptionComplex|None, sc: QStyle.SubControl, widget: QWidget|None = None) -> QRect");

extern "C" {static PyObject *meth_QCommonStyle_subControlRect(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QCommonStyle_subControlRect(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QCommonStyle)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        const ::QStyleOptionComplex* a1;
        ::QStyle::SubControl a2;
        const ::QWidget* a3 = 0;
        const ::QCommonStyle *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_widget,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BEJ8E|J8", &sipSelf, sipType_QCommonStyle, &sipCpp, sipType_QStyle_ComplexControl, &a0, sipType_QStyleOptionComplex, &a1, sipType_QStyle_SubControl, &a2, sipType_QWidget, &a3))
        {
            ::QRect*sipRes;

            sipRes = new ::QRect((sipSelfWasArg ? sipCpp->::QCommonStyle::subControlRect(static_cast< ::QStyle::ComplexControl>(a0), a1, a2, a3) : sipCpp->subControlRect(static_cast< ::QStyle::ComplexControl>(a0), a1, a2, a3)));

            return sipConvertFromNewType(sipRes, sipType_QRect, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCommonStyle, sipName_subControlRect, doc_QCommonStyle_subControlRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCommonStyle_sizeFromContents, "sizeFromContents(self, ct: QStyle.ContentsType, opt: QStyleOption|None, contentsSize: QSize, widget: QWidget|None = None) -> QSize");

extern "C" {static PyObject *meth_QCommonStyle_sizeFromContents(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QCommonStyle_sizeFromContents(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QCommonStyle)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        const ::QStyleOption* a1;
        const ::QSize* a2;
        const ::QWidget* a3 = 0;
        const ::QCommonStyle *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_widget,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BEJ8J9|J8", &sipSelf, sipType_QCommonStyle, &sipCpp, sipType_QStyle_ContentsType, &a0, sipType_QStyleOption, &a1, sipType_QSize, &a2, sipType_QWidget, &a3))
        {
            ::QSize*sipRes;

            sipRes = new ::QSize((sipSelfWasArg ? sipCpp->::QCommonStyle::sizeFromContents(static_cast< ::QStyle::ContentsType>(a0), a1, *a2, a3) : sipCpp->sizeFromContents(static_cast< ::QStyle::ContentsType>(a0), a1, *a2, a3)));

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCommonStyle, sipName_sizeFromContents, doc_QCommonStyle_sizeFromContents);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCommonStyle_pixelMetric, "pixelMetric(self, m: QStyle.PixelMetric, option: QStyleOption|None = None, widget: QWidget|None = None) -> int");

extern "C" {static PyObject *meth_QCommonStyle_pixelMetric(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QCommonStyle_pixelMetric(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QCommonStyle)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        const ::QStyleOption* a1 = 0;
        const ::QWidget* a2 = 0;
        const ::QCommonStyle *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_option,
            sipName_widget,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BE|J8J8", &sipSelf, sipType_QCommonStyle, &sipCpp, sipType_QStyle_PixelMetric, &a0, sipType_QStyleOption, &a1, sipType_QWidget, &a2))
        {
            int sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QCommonStyle::pixelMetric(static_cast< ::QStyle::PixelMetric>(a0), a1, a2) : sipCpp->pixelMetric(static_cast< ::QStyle::PixelMetric>(a0), a1, a2));

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCommonStyle, sipName_pixelMetric, doc_QCommonStyle_pixelMetric);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCommonStyle_styleHint, "styleHint(self, sh: QStyle.StyleHint, option: QStyleOption|None = None, widget: QWidget|None = None, returnData: QStyleHintReturn|None = None) -> int");

extern "C" {static PyObject *meth_QCommonStyle_styleHint(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QCommonStyle_styleHint(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QCommonStyle)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        const ::QStyleOption* a1 = 0;
        const ::QWidget* a2 = 0;
        ::QStyleHintReturn* a3 = 0;
        const ::QCommonStyle *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_option,
            sipName_widget,
            sipName_returnData,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BE|J8J8J8", &sipSelf, sipType_QCommonStyle, &sipCpp, sipType_QStyle_StyleHint, &a0, sipType_QStyleOption, &a1, sipType_QWidget, &a2, sipType_QStyleHintReturn, &a3))
        {
            int sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QCommonStyle::styleHint(static_cast< ::QStyle::StyleHint>(a0), a1, a2, a3) : sipCpp->styleHint(static_cast< ::QStyle::StyleHint>(a0), a1, a2, a3));

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCommonStyle, sipName_styleHint, doc_QCommonStyle_styleHint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCommonStyle_standardPixmap, "standardPixmap(self, sp: QStyle.StandardPixmap, option: QStyleOption|None = None, widget: QWidget|None = None) -> QPixmap");

extern "C" {static PyObject *meth_QCommonStyle_standardPixmap(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QCommonStyle_standardPixmap(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QCommonStyle)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        const ::QStyleOption* a1 = 0;
        const ::QWidget* a2 = 0;
        const ::QCommonStyle *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_option,
            sipName_widget,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BE|J8J8", &sipSelf, sipType_QCommonStyle, &sipCpp, sipType_QStyle_StandardPixmap, &a0, sipType_QStyleOption, &a1, sipType_QWidget, &a2))
        {
            ::QPixmap*sipRes;

            sipRes = new ::QPixmap((sipSelfWasArg ? sipCpp->::QCommonStyle::standardPixmap(static_cast< ::QStyle::StandardPixmap>(a0), a1, a2) : sipCpp->standardPixmap(static_cast< ::QStyle::StandardPixmap>(a0), a1, a2)));

            return sipConvertFromNewType(sipRes, sipType_QPixmap, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCommonStyle, sipName_standardPixmap, doc_QCommonStyle_standardPixmap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCommonStyle_generatedIconPixmap, "generatedIconPixmap(self, iconMode: QIcon.Mode, pixmap: QPixmap, opt: QStyleOption|None) -> QPixmap");

extern "C" {static PyObject *meth_QCommonStyle_generatedIconPixmap(PyObject *, PyObject *);}
static PyObject *meth_QCommonStyle_generatedIconPixmap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QCommonStyle)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QIcon::Mode a0;
        const ::QPixmap* a1;
        const ::QStyleOption* a2;
        const ::QCommonStyle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BEJ9J8", &sipSelf, sipType_QCommonStyle, &sipCpp, sipType_QIcon_Mode, &a0, sipType_QPixmap, &a1, sipType_QStyleOption, &a2))
        {
            ::QPixmap*sipRes;

            sipRes = new ::QPixmap((sipSelfWasArg ? sipCpp->::QCommonStyle::generatedIconPixmap(a0, *a1, a2) : sipCpp->generatedIconPixmap(a0, *a1, a2)));

            return sipConvertFromNewType(sipRes, sipType_QPixmap, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCommonStyle, sipName_generatedIconPixmap, doc_QCommonStyle_generatedIconPixmap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCommonStyle_standardIcon, "standardIcon(self, standardIcon: QStyle.StandardPixmap, option: QStyleOption|None = None, widget: QWidget|None = None) -> QIcon");

extern "C" {static PyObject *meth_QCommonStyle_standardIcon(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QCommonStyle_standardIcon(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QCommonStyle)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        const ::QStyleOption* a1 = 0;
        const ::QWidget* a2 = 0;
        const ::QCommonStyle *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_option,
            sipName_widget,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BE|J8J8", &sipSelf, sipType_QCommonStyle, &sipCpp, sipType_QStyle_StandardPixmap, &a0, sipType_QStyleOption, &a1, sipType_QWidget, &a2))
        {
            ::QIcon*sipRes;

            sipRes = new ::QIcon((sipSelfWasArg ? sipCpp->::QCommonStyle::standardIcon(static_cast< ::QStyle::StandardPixmap>(a0), a1, a2) : sipCpp->standardIcon(static_cast< ::QStyle::StandardPixmap>(a0), a1, a2)));

            return sipConvertFromNewType(sipRes, sipType_QIcon, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCommonStyle, sipName_standardIcon, doc_QCommonStyle_standardIcon);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCommonStyle_layoutSpacing, "layoutSpacing(self, control1: QSizePolicy.ControlType, control2: QSizePolicy.ControlType, orientation: Qt.Orientation, option: QStyleOption|None = None, widget: QWidget|None = None) -> int");

extern "C" {static PyObject *meth_QCommonStyle_layoutSpacing(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QCommonStyle_layoutSpacing(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QCommonStyle)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QSizePolicy::ControlType a0;
        ::QSizePolicy::ControlType a1;
        ::Qt::Orientation a2;
        const ::QStyleOption* a3 = 0;
        const ::QWidget* a4 = 0;
        const ::QCommonStyle *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_option,
            sipName_widget,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BEEE|J8J8", &sipSelf, sipType_QCommonStyle, &sipCpp, sipType_QSizePolicy_ControlType, &a0, sipType_QSizePolicy_ControlType, &a1, sipType_Qt_Orientation, &a2, sipType_QStyleOption, &a3, sipType_QWidget, &a4))
        {
            int sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QCommonStyle::layoutSpacing(a0, a1, a2, a3, a4) : sipCpp->layoutSpacing(a0, a1, a2, a3, a4));

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCommonStyle, sipName_layoutSpacing, doc_QCommonStyle_layoutSpacing);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QCommonStyle(void *, const sipTypeDef *);}
static void *cast_QCommonStyle(void *sipCppV, const sipTypeDef *targetType)
{
    ::QCommonStyle *sipCpp = reinterpret_cast< ::QCommonStyle *>(sipCppV);

    if (targetType == sipType_QCommonStyle)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QStyle)->ctd_cast(static_cast< ::QStyle *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QCommonStyle(void *, int);}
static void release_QCommonStyle(void *sipCppV, int)
{
    ::QCommonStyle *sipCpp = reinterpret_cast< ::QCommonStyle *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QCommonStyle(Py_ssize_t);}
static void *array_QCommonStyle(Py_ssize_t sipNrElem)
{
    return new ::QCommonStyle[sipNrElem];
}


extern "C" {static void array_delete_QCommonStyle(void *);}
static void array_delete_QCommonStyle(void *sipCpp)
{
    delete[] reinterpret_cast< ::QCommonStyle *>(sipCpp);
}


extern "C" {static void dealloc_QCommonStyle(sipSimpleWrapper *);}
static void dealloc_QCommonStyle(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQCommonStyle *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QCommonStyle(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QCommonStyle(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QCommonStyle(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQCommonStyle *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new sipQCommonStyle();

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QCommonStyle[] = {{282, 255, 1}};


static PyMethodDef methods_QCommonStyle[] = {
    {sipName_drawComplexControl, SIP_MLMETH_CAST(meth_QCommonStyle_drawComplexControl), METH_VARARGS|METH_KEYWORDS, doc_QCommonStyle_drawComplexControl},
    {sipName_drawControl, SIP_MLMETH_CAST(meth_QCommonStyle_drawControl), METH_VARARGS|METH_KEYWORDS, doc_QCommonStyle_drawControl},
    {sipName_drawPrimitive, SIP_MLMETH_CAST(meth_QCommonStyle_drawPrimitive), METH_VARARGS|METH_KEYWORDS, doc_QCommonStyle_drawPrimitive},
    {sipName_generatedIconPixmap, meth_QCommonStyle_generatedIconPixmap, METH_VARARGS, doc_QCommonStyle_generatedIconPixmap},
    {sipName_hitTestComplexControl, SIP_MLMETH_CAST(meth_QCommonStyle_hitTestComplexControl), METH_VARARGS|METH_KEYWORDS, doc_QCommonStyle_hitTestComplexControl},
    {sipName_layoutSpacing, SIP_MLMETH_CAST(meth_QCommonStyle_layoutSpacing), METH_VARARGS|METH_KEYWORDS, doc_QCommonStyle_layoutSpacing},
    {sipName_pixelMetric, SIP_MLMETH_CAST(meth_QCommonStyle_pixelMetric), METH_VARARGS|METH_KEYWORDS, doc_QCommonStyle_pixelMetric},
    {sipName_polish, meth_QCommonStyle_polish, METH_VARARGS, doc_QCommonStyle_polish},
    {sipName_sizeFromContents, SIP_MLMETH_CAST(meth_QCommonStyle_sizeFromContents), METH_VARARGS|METH_KEYWORDS, doc_QCommonStyle_sizeFromContents},
    {sipName_standardIcon, SIP_MLMETH_CAST(meth_QCommonStyle_standardIcon), METH_VARARGS|METH_KEYWORDS, doc_QCommonStyle_standardIcon},
    {sipName_standardPixmap, SIP_MLMETH_CAST(meth_QCommonStyle_standardPixmap), METH_VARARGS|METH_KEYWORDS, doc_QCommonStyle_standardPixmap},
    {sipName_styleHint, SIP_MLMETH_CAST(meth_QCommonStyle_styleHint), METH_VARARGS|METH_KEYWORDS, doc_QCommonStyle_styleHint},
    {sipName_subControlRect, SIP_MLMETH_CAST(meth_QCommonStyle_subControlRect), METH_VARARGS|METH_KEYWORDS, doc_QCommonStyle_subControlRect},
    {sipName_subElementRect, SIP_MLMETH_CAST(meth_QCommonStyle_subElementRect), METH_VARARGS|METH_KEYWORDS, doc_QCommonStyle_subElementRect},
    {sipName_unpolish, meth_QCommonStyle_unpolish, METH_VARARGS, doc_QCommonStyle_unpolish}
};

PyDoc_STRVAR(doc_QCommonStyle, "\1QCommonStyle()");


static pyqt6ClassPluginDef plugin_QCommonStyle = {
    &::QCommonStyle::staticMetaObject,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWidgets_QCommonStyle = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QCommonStyle,
        SIP_NULLPTR,
        &plugin_QCommonStyle,
    },
    {
        sipNameNr_QCommonStyle,
        {0, 0, 1},
        15, methods_QCommonStyle,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QCommonStyle,
    -1,
    -1,
    supers_QCommonStyle,
    SIP_NULLPTR,
    init_type_QCommonStyle,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QCommonStyle,
    SIP_NULLPTR,
    array_QCommonStyle,
    SIP_NULLPTR,
    release_QCommonStyle,
    cast_QCommonStyle,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QCommonStyle,
    sizeof (::QCommonStyle),
};
